
# Slot: list_value_specification_constant


Grouping for metamodel slots that constrain members of a multivalued slot value to equal a specified constant

URI: [linkml:list_value_specification_constant](https://w3id.org/linkml/list_value_specification_constant)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children

 *  [all_members](all_members.md)
 *  [equals_number_in](equals_number_in.md)
 *  [equals_string_in](equals_string_in.md)
 *  [has_member](has_member.md)

## Used by

